sqlobject.converters module — SQLObject 3.9.1 documentation

# sqlobject.converters module

`sqlobject.converters.` `BoolConverter`(value, db)

class `sqlobject.converters.` `ConverterRegistry`

  Bases: `object`

  `lookupConverter`(value, default=None)
  `registerConverter`(typ, func)

`sqlobject.converters.` `DateConverter`(value, db)

`sqlobject.converters.` `DateTimeConverter`(value, db)

`sqlobject.converters.` `DateTimeConverterMS`(value, db)

`sqlobject.converters.` `DecimalConverter`(value, db)

`sqlobject.converters.` `FloatConverter`(value, db)

`sqlobject.converters.` `IntConverter`(value, db)

`sqlobject.converters.` `LongConverter`(value, db)

`sqlobject.converters.` `NoneConverter`(value, db)

`sqlobject.converters.` `SequenceConverter`(value, db)

`sqlobject.converters.` `StringLikeConverter`(value, db)

`sqlobject.converters.` `StructTimeConverter`(value, db)

`sqlobject.converters.` `TimeConverter`(value, db)

`sqlobject.converters.` `TimeConverterMS`(value, db)

`sqlobject.converters.` `TimedeltaConverter`(value, db)

`sqlobject.converters.` `lookupConverter`(value, default=None)

`sqlobject.converters.` `quote_str`(s, db)

`sqlobject.converters.` `registerConverter`(typ, func)

`sqlobject.converters.` `sqlrepr`(obj, db=None)

`sqlobject.converters.` `unquote_str`(s)